==> apache-artemis-2.33.0-source-release.tar.gz: apache-artemis-2.33.0/tests/unit-tests/src/test/java/org/apache/activemq/artemis/tests/unit/util/EmptyListTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.tests.unit.util;

import java.util.Iterator;
import java.util.NoSuchElementException;

import org.apache.activemq.artemis.utils.collections.EmptyList;
import org.apache.activemq.artemis.utils.collections.LinkedList;
import org.junit.Assert;
import org.junit.Test;

public class EmptyListTest {

   @Test
   public void testEmpty() {
      LinkedList<String> stringEmpty = EmptyList.getEmptyList();
      Assert.assertEquals(0, stringEmpty.size());
      Iterator<String> stringIterator = stringEmpty.iterator();
      Assert.assertFalse(stringIterator.hasNext());

      try {
         stringIterator.next();
         Assert.fail("Exception expected");
      } catch (NoSuchElementException e) {
      }

      try {
         stringEmpty.get(0);
         Assert.fail("Exception expected");
      } catch (IndexOutOfBoundsException e) {
      }
   }

}

==> apache-artemis-2.42.0-source-release.tar.gz: apache-artemis-2.42.0/tests/unit-tests/src/test/java/org/apache/activemq/artemis/tests/unit/util/EmptyListTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.tests.unit.util;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.fail;

import java.util.Iterator;
import java.util.NoSuchElementException;

import org.apache.activemq.artemis.utils.collections.EmptyList;
import org.apache.activemq.artemis.utils.collections.LinkedList;
import org.junit.jupiter.api.Test;

public class EmptyListTest {

   @Test
   public void testEmpty() {
      LinkedList<String> stringEmpty = EmptyList.getEmptyList();
      assertEquals(0, stringEmpty.size());
      Iterator<String> stringIterator = stringEmpty.iterator();
      assertFalse(stringIterator.hasNext());

      try {
         stringIterator.next();
         fail("Exception expected");
      } catch (NoSuchElementException e) {
      }

      try {
         stringEmpty.get(0);
         fail("Exception expected");
      } catch (IndexOutOfBoundsException e) {
      }
   }

}
